@@ -25,15 +25,13 @@ attached”.
 
 =head1 STATUS
 
-This distribution is an experimental effort.
-
-Note that this distribution’s interface can still change. If you decide
-to use CBOR::Free in your project, please always check the changelog before
-upgrading.
+This distribution is an experimental effort. Its interface is still
+subject to change. If you decide to use CBOR::Free in your project,
+please always check the changelog before upgrading.
 
 =head1 FUNCTIONS
 
-=head2 $cbor = encode( $DATA )
+=head2 $cbor = encode( $DATA, %OPTS )
 
 Encodes a data structure or non-reference scalar to CBOR.
 The encoder recognizes and encodes integers, floats, binary and UTF-8
@@ -42,6 +40,15 @@ L<Types::Serialiser> booleans, and undef (encoded as null).
 
 The encoder currently does not handle any other blessed references.
 
+%OPTS may be:
+
+=over
+
+=item * C<canonical> - A boolean that makes the function output
+CBOR in L<canonical form|https://tools.ietf.org/html/rfc7049#section-3.9>.
+
+=back
+
 Notes on mapping Perl to CBOR:
 
 =over
@@ -95,23 +102,39 @@ C<CBOR::Free::true()>, C<CBOR::Free::false()>,
 C<$CBOR::Free::true>, and C<$CBOR::Free::false> are defined as
 convenience aliases for the equivalent L<Types::Serialiser> values.
 
+=head1 FRACTIONAL (FLOATING-POINT) NUMBERS
+
+Floating-point numbers are encoded in CBOR as IEEE 754 half-, single-,
+or double-precision. If your Perl is compiled to use “long double”
+floating-point numbers, you may see rounding errors when converting
+to/from CBOR. If that’s a problem for you, append an empty string to
+your floating-point numbers, which will cause CBOR to encode
+them as strings.
+
+=head1 INTEGER LIMITS
+
+CBOR handles up to 64-bit unsigned and signed integers. Most Perls
+nowadays can handle this just fine, but if yours can’t then you’ll
+get an exception whenever trying to parse an integer that can’t be
+represented with 32 bits. This means:
+
+=over
+
+=item * Anything greater than 0xffff_ffff (4,294,967,295)
+
+=item * Anything less than -0x8000_0000 (2,147,483,648)
+
+=back
+
+Note that even 64-bit Perls can’t parse negatives that are less than
+-0x8000_0000_0000_0000 (-9,223,372,036,854,775,808); these also prompt an
+exception since Perl can’t handle them.
+
 =head1 ERROR HANDLING
 
 Most errors are represented via instances of subclasses of
 L<CBOR::Free::X>.
 
-=head1 TODO
-
-=over
-
-=item * Add canonical encode().
-
-=item * Make it faster. On some platforms (e.g., Linux) it appears to be
-faster than L<JSON::XS> but not quite as fast as L<CBOR::XS>; on others
-(e.g., macOS), it’s slower than both.
-
-=back
-
 =head1 AUTHOR
 
 L<Gasper Software Consulting|http://gaspersoftware.com> (FELIPE)
@@ -122,8 +145,13 @@ This code is licensed under the same license as Perl itself.
 
 =head1 SEE ALSO
 
-L<CBOR::XS> is an older, GPL-licensed CBOR module. It implements
+L<CBOR::XS> is an older CBOR module on CPAN. It implements
 some behaviors around CBOR tagging that you might find useful.
+Its maintainer has L<abandoned support for Perl versions from 5.22
+onward|http://blog.schmorp.de/2015-06-06-stableperl-faq.html>, though,
+and its GPL license limits its usefulness in
+commercial L<perlcc|https://metacpan.org/pod/distribution/B-C/script/perlcc.PL>
+applications.
 
 =cut
 
@@ -139,7 +167,7 @@ use CBOR::Free::Tagged;
 our ($VERSION);
 
 BEGIN {
-    $VERSION = '0.01_09';
+    $VERSION = '0.03_01';
     XSLoader::load();
 }
 
@@ -147,10 +175,18 @@ our ($true, $false);
 *true = *Types::Serialiser::true;
 *false = *Types::Serialiser::false;
 
+sub encode {
+    my %opts = @_[ 1 .. $#_ ];
+
+    return $opts{'canonical'} ? _c_encode_canonical($_[0]) : _c_encode($_[0]);
+}
+
 sub tag {
     return CBOR::Free::Tagged->new(@_);
 }
 
+#----------------------------------------------------------------------
+
 sub _die_recursion {
     die CBOR::Free::X->create( 'Recursion', _MAX_RECURSION());
 }
